Skip to contents

This function takes user defined Industry Group, Industry, Division, Subdivision and Organization Types and filters population of NTEE2 codes to find codes that match user inputs.

Usage

parse_ntee(ntee.group, ntee.code, ntee.orgtype)

Arguments

ntee.group

character vector. Vector of desired Industry Group codes to filter. Use "all" to include all possible codes.

ntee.code

character vector. Sequence of desired Industry, Division and Subdivision codes (old code structure) to use in filtering. Use "all" to include all possible codes. Can also provide only partial codes. For example "A" or "Axx" will query NTEE2 codes based on Industry group "A" and all division and subdivisions.

ntee.orgtype

character vector. Vector of Organization Types. Use "all" to include all possible codes.

Value

list of matched NTEE2 codes

Details

Function that generates population of NTEE2 codes and filters codes that match user inputs