A complete function takes any user input values from the arguments: ntee.group ntee.code ntee.orgtype And returns the correct list of NTEE codes that match the filter requirements. It will also raise an error if the user tries argument values that are undefined and print an informative message.
Source:R/ntee_main.R
parse_ntee.RdThis function takes user defined Industry Group, Industry, Division, Subdivision and Organization Types and filters population of NTEE2 codes to find codes that match user inputs.
Arguments
- ntee.group
character vector. Vector of desired Industry Group codes to filter. Use "all" to include all possible codes.
- ntee.code
character vector. Sequence of desired Industry, Division and Subdivision codes (old code structure) to use in filtering. Use "all" to include all possible codes. Can also provide only partial codes. For example "A" or "Axx" will query NTEE2 codes based on Industry group "A" and all division and subdivisions.
- ntee.orgtype
character vector. Vector of Organization Types. Use "all" to include all possible codes.